# A spectral sensitivity analyser

The electroretinogram (ERG) technique, for example,
can be used to measure eyes' responsivness to differently colored light flashes.
Spectronator is a graphical tool that quantifies spectral sensitivity from
this time series data.
